@@ -1,7 +1,7 @@
 from argparse import Namespace
 from youtube_dl.version import __version__ as youtube_dl_version
 
-import ytrss
+from ytrss.core.version import Version
 from ytrss.commands import BaseCommand
 from ytrss.core.helpers.logging import logger
 
@@ -15,6 +15,6 @@ class VersionCommand(BaseCommand):
         BaseCommand.__init__(self, "version")
 
     def run(self, options: Namespace) -> int:
-        logger.info("%s: %s", ytrss.__name__, ytrss.__version__)
+        logger.info("ytrss: %s", Version().version)
         logger.info("youtube_dl: %s", youtube_dl_version)
         return 0
